#
# spec file for package python-pystache
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pystache
Version:        0.6.7
Release:        1.1
Summary:        Mustache for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/defunkt/pystache
Source:         https://files.pythonhosted.org/packages/source/p/pystache/pystache-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%description
Pystache is a Python implementation of Mustache. Mustache is a
framework-agnostic, logic-free templating system inspired by
ctemplate and etc. Like ctemplate, Mustache "emphasises separating
logic from presentation: it is impossible to embed application
logic in this template language."

The mustache(5) man page provides a good introduction to Mustache's
syntax. For a more complete (and more current) description of
Mustache's behaviour, see the official Mustache spec:
https://github.com/mustache/spec.

%python_subpackages

%prep
%setup -q -n pystache-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pystache
%python_clone -a %{buildroot}%{_bindir}/pystache-test
%{python_expand %fdupes %{buildroot}%$python_sitelib/}

%check
%pytest

%post
%{python_install_alternative pystache pystache-test}

%postun
%{python_uninstall_alternative pystache pystache-test}

%files %{python_files}
%license LICENSE
%doc HISTORY.md README.rst TODO.rst
%python_alternative %{_bindir}/pystache
%python_alternative %{_bindir}/pystache-test
%{python_sitelib}/pystache/
%{python_sitelib}/pystache-%{version}.dist-info

%changelog
* Fri Jan 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.7
  * fix: Fail on unmatched tags.
- from version 0.6.6
  * Update README to match supported versions.
  * Update pre-commit.
  * Update pyproject.toml with 3.12 and 3.13 Python versions.
  * Update tox config to use Python 3.12 and 3.13 versions.
  * Update yml files with Python 3.12 and 3.13.
  * Update changelog for v0.6.5 a bit belatedly.
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.5:
  * Use the content-type for RST that pypi now wants
  * Add full sphinx apidoc build, include readme/extras.
  * Fix included filename and link cleanup.
  * Remove more py2 cruft from doctesting (py3.10 warnings)
  * Update maintainer info and spec test cmd.
  * Use updated bandit action and workflow excludes (exclude test)
  * Use current org-level coverage workflow.
* Thu Jul 27 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Dec 11 2021 Dirk Müller <dmueller@suse.com>
- udpate to 0.6.0:
  * Bump spec versions to latest => v1.1.3
  * Modernize python and CI tools, update docs/doctests
  * Update unicode conversion test for py3-only
  * Add pep8speaks cfg, cleanup warnings
  * Remove superfluous setup test/unused imports
  * Use correct wheel name in release workflow, limit wheels
  * Add install check/test of downloaded wheel
  * Update/add ci workflows and tox cfg, bump to next dev0 version
  * fix document processing, update pandoc args and history
  * add release.yml to CI, test env settings
  * fix bogus commit message, update versions and tox cf
  * add post-test steps for building pkgs with/without doc updates
  * Bugfix: test_specloader.py: fix test_find__with_directory on other OSs
  * Bugfix: pystache/loader.py: remove stray windows line-endings
  * fix crufty (and insecure) http urls
  * Bugfix: modernize python versions (keep py27)
* Thu Jul  2 2020 pgajdos@suse.com
- switch from nose to pytest
* Mon Jul 16 2018 tchvatal@suse.com
- Drop the devel package from buildrequires
* Sun Jul  2 2017 sor.alexei@meowr.ru
- Update for the multipython build.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Fri Aug 29 2014 toddrme2178@gmail.com
- Initial version
